@@ -4,6 +4,8 @@ local vm         = require 'vm'
 local findSource = require 'core.find-source'
 local guide      = require 'parser.guide'
 local rpath      = require 'workspace.require-path'
+local jumpSource = require 'core.jump-source'
+local wssymbol   = require 'core.workspace-symbol'
 
 local function sortResults(results)
     -- 先按照顺序排序
@@ -52,7 +54,9 @@ local accept = {
     ['doc.extends.name'] = true,
     ['doc.alias.name']   = true,
     ['doc.see.name']     = true,
-    ['doc.see.field']    = true,
+    ['doc.cast.name']    = true,
+    ['doc.enum.name']    = true,
+    ['doc.field.name']   = true,
 }
 
 local function checkRequire(source, offset)
@@ -74,7 +78,7 @@ local function checkRequire(source, offset)
         return nil
     end
     if     libName == 'require' then
-        return rpath.findUrisByRequirePath(guide.getUri(source), literal)
+        return rpath.findUrisByRequireName(guide.getUri(source), literal)
     elseif libName == 'dofile'
     or     libName == 'loadfile' then
         return workspace.findUrisByFilePath(literal)
@@ -103,6 +107,26 @@ local function convertIndex(source)
     return source
 end
 
+---@async
+---@param source parser.object
+---@param results table
+local function checkSee(source, results)
+    if source.type ~= 'doc.see.name' then
+        return
+    end
+    local symbols = wssymbol(source[1], guide.getUri(source))
+    for _, symbol in ipairs(symbols) do
+        if symbol.name == source[1] then
+            results[#results+1] = {
+                target = symbol.source,
+                source = source,
+                uri    = guide.getUri(symbol.source),
+            }
+        end
+    end
+end
+
+---@async
 return function (uri, offset)
     local ast = files.getState(uri)
     if not ast then
@@ -130,9 +154,14 @@ return function (uri, offset)
         end
     end
 
+    checkSee(source, results)
+
     local defs = vm.getDefs(source)
 
     for _, src in ipairs(defs) do
+        if src.type == 'global' then
+            goto CONTINUE
+        end
         local root = guide.getRoot(src)
         if not root then
             goto CONTINUE
@@ -165,11 +194,20 @@ return function (uri, offset)
         if src.type == 'doc.alias' then
             src = src.alias
         end
+        if src.type == 'doc.enum' then
+            src = src.enum
+        end
+        if src.type == 'doc.type.field' then
+            src = src.name
+        end
         if src.type == 'doc.class.name'
-        or src.type == 'doc.alias.name' then
+        or src.type == 'doc.alias.name'
+        or src.type == 'doc.enum.name' then
             if  source.type ~= 'doc.type.name'
             and source.type ~= 'doc.extends.name'
-            and source.type ~= 'doc.see.name' then
+            and source.type ~= 'doc.see.name'
+            and source.type ~= 'doc.class.name'
+            and source.type ~= 'doc.alias.name' then
                 goto CONTINUE
             end
         end
@@ -193,6 +231,7 @@ return function (uri, offset)
     end
 
     sortResults(results)
+    jumpSource(results)
 
     return results
 end
